(mem-store servers & opts)Creates session storage backed by memcached with zero or more options(any order):
:protocol Protocol to talk with memcached,a string in "text" "binary" or "kestrel",default is text.
:hash Hash algorithm,a string in "consistent", "standard" or "phpmemcache", default is standard hash.
:pool Connection pool size,default is 1
:timeout Operation timeout in milliseconds,default is five seconds.
:name A name to define a memcached client instance
Creates session storage backed by memcached with zero or more options(any order): :protocol Protocol to talk with memcached,a string in "text" "binary" or "kestrel",default is text. :hash Hash algorithm,a string in "consistent", "standard" or "phpmemcache", default is standard hash. :pool Connection pool size,default is 1 :timeout Operation timeout in milliseconds,default is five seconds. :name A name to define a memcached client instance
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |